raise "Can't run this file directly" unless defined? $lib_dir
# Net Responsibility
#
# Copyright (C) 2007 Scott Severance
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#
# Author:
#	Scott Severance <http://www.scottseverance.us>

require 'date'
require "#{$lib_dir}my_date"
require 'yaml'

class Logfile
  #include YAML
  def initialize(log)
    if log.respond_to?(:logfile)
        @logfile = log.logfile
    elsif log.class == "String"
        @logfile = File.expand_path(log)
    else raise "I don't know how to handle this log file: #{log.inspect}"
    end
    
    parse
    list_dates
  end
  
  def sort_events_by_date(dates = @dates, data = @data)
    list = {}
    dates.to_a.each do |date|
      events = []
      re = Regexp.new("^#{date}")
      data.each do |event|
        key = 'time'
        begin
          events.push(event) if event.fetch(key) =~ re
        rescue IndexError
          if key == 'time'
            key = 'timestamp'
            retry
          else raise
          end
        end
      end
      list[date] = events
    end
    #print list.to_yaml
    list
  end
  
  # events is a hash of all the events for a given day
  def sort_events_by_type(events)
    types = event_types(events)
    events.each do |event|
      event.each do |v|
        next if v.class == :String
        v.each do |v2|
          next if v2.respond_to? :capitalize
          type = v2.delete('type')
          types[type].push v2.sort unless type == nil
        end
      end
    end
    #print types.to_yaml
    types
  end
  
  # events is an array of url events in the format returned by
  # sort_events_by_type
  def sort_events_by_hostname(events)
    hosts = list_hostnames(events)
    re = hostname_re
    events.to_a.each do |event|
      raise "This method can only handle URL events" unless event[1][0] == 'url'
      host = event[1][1].gsub(re,'\1')
      date = DateTime.parse event[0][1]
      path = event[1][1].gsub(re,'\2')
      tmp = {'date' => date, 'path' => path}
      hosts[host].push tmp
    end
    #hosts.each_key do |k|
    #  hosts[k].sort { |x,y| x['date'] <=> y['date']}
    #end
    #print hosts.to_yaml
    hosts
  end
  
  private
  
  def hostname_re
    Regexp.new("^.*//([^/]+)(/.*)$")
  end
  
  def list_hostnames(events)
    names = {}
    tmp = []
    re = hostname_re
    events.to_a.each do |event|
      tmp.push(event[1][1].gsub(re,'\1'))
    end
    tmp.uniq.each {|host| names[host] = []}
    #p names
    names
  end
  
  def event_types(events)
    types = {}
    tmp = []
    events.each do |event|
      event.each do |v|
        next if v.class == :String
        v.each do |v2|
          next if v2.respond_to? :capitalize
          tmp.push v2['type']
        end
      end
    end
    tmp.uniq!
    tmp.each { |v| types[v] = [] }
    types
  end
  
  def parse
    data = []
    File.open(@logfile) do |file|
      YAML.each_document(file) { |f2| data.push f2 }
    end
    data2 = []
    data.each { |arr| data2 += arr }
    
    @data = data2
  end
  
  def list_dates
    data = []
    @data.each do |item|
      key = "time"
      begin
        data.push(item.fetch(key).gsub(/^([^\s]+)\s.*/,'\1'))
      rescue IndexError
        if key == "time"
          key = "timestamp"
          retry
        else raise
        end
      end
    end
    @dates = data.to_a.uniq.sort
  end
end