raise "Can't run this file directly" unless defined? $lib_dir
# Net Responsibility
#
# Copyright (C) 2007 Scott Severance
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#
# Author:
#	Scott Severance <http://www.scottseverance.us>

require 'getoptlong'
require 'yaml'

class Options  
  def initialize
    set_options
    settings = read_config(@config)
    settings.each do |key, value|
      instance_variable_set("@#{key}", value)
      getter = proc do
        instance_variable_get("@#{key}")
      end
      setter = proc do |v|
        instance_variable_set("@#{key}", v)
      end
      self.class.send(:define_method,key,getter)
      self.class.send(:define_method,"#{key}=",setter)
    end
    @daemonize = self.pidfile if @daemonize == "pidfile"
  end
  
  def read_config(filename)
    settings = nil
    begin
      File.open(filename) { |f| settings = YAML::load(f) }
    rescue Errno::ENOENT
      $stderr.print "The configuration file #{filename} doesn't exist.\n"
      exit(1)
    end
    settings
  end
  
  def set_options
    @config = Options.default_configfile
    @daemonize = "pidfile"
    @debug = false
    begin
      opts = GetoptLong.new(
                           #['--logfile','-l',GetoptLong::REQUIRED_ARGUMENT],
                           ['--config','-c',GetoptLong::REQUIRED_ARGUMENT],
                           ['--nodaemon','-d',GetoptLong::NO_ARGUMENT],
                           ['--debug',GetoptLong::NO_ARGUMENT],
                           ['--help','-h',GetoptLong::NO_ARGUMENT]
                           )
      opts.each do |option, argument|
        case option
          when '--help'
            usage # this method must be defined in a file that requires
                  # this one.
            exit
          when '--nodaemon'
            @daemonize = false
          #when '--logfile'
          #  @logfile = File.expand_path(argument)
          when '--config'
            @config = File.expand_path(argument)
          when '--debug'
            @debug = $debug_available
            unless @debug
              puts "The debugger isn't installed. Exiting."
              exit 1 
            end
        end
      end
    rescue
      $stderr.print "\n"
      usage
      exit 1
    end
  end
  
  def self.default_configfile
    if $lib_dir =~ Regexp.new("^/usr/share")
      '/etc/net-responsibility.conf'
    else
      "%s/net-responsibility.conf" % $0.gsub(Regexp.new("^(.*)/[^/]*$"), '\1')
    end
  end
  
  def self.default_logfile
    '/var/log/net-responsibility.log'
    #File.expand_path('net-responsibility.log')
  end

  def to_s
    str = ""
    instance_variables.each do |var|
      str += "%s = %s\n" % [var.gsub(/^@*/,''),
                            instance_variable_get(var).inspect]
    end
    str.chomp
  end
  alias_method :inspect, :to_s
  attr_accessor :config, :daemonize, :debug
  private :read_config, :set_options
end