raise "Can't run this file directly" unless defined? $lib_dir
# Net Responsibility
#
# Copyright (C) 2007 Scott Severance
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#
# Author:
#	Scott Severance <http://www.scottseverance.us>

require "net/smtp"

require "#{$lib_dir}options"
require "#{$lib_dir}my_date"
require "#{$lib_dir}exceptions"
require "#{$lib_dir}syslog"

class Report_mailer
  def initialize(options = nil)
    options = Options.new unless options
    @options = options
    unless options.respond_to? :smtp_server
      t  = "Your configuration file, #{options.config}, is missing the "
      t += "section 'smtp_server'. I can't continue without it. Please "
      t += "either repair the file, or uninstall Net Responsibility, "
      t += "allowing the uninstaller to remove the config file, then "
      t += "reinstall Net Responsibility.\n"
      t += "Exiting."
      Syslog.log t, 'syslog'
      exit 1
    end
    @smtp_options = options.smtp_server
    @smtp_options["email_from"] = options.email_from
    @smtp_options["email_to"] = options.email_to
    @smtp_options['name'] = options.name
    @smtp_options['use_smtp']
  end
  
  def create_message(subject,text)
    opts = @smtp_options
    date = DateTime.now
    t  = ''
    t += "Subject: %s\n" % subject.gsub(Regexp.new('(\r|\n)'), ' ')
    t += "Date: %s\n" % date.email_date
    t += "Message-Id: %s\n" % [date.ld, date.sec_fraction.to_s.gsub(/\//,'_'),
                                 opts['email_from']].join('.')
    t += "Content-Type: text/plain\n\n"
    t += text
    return t
  end
  
  def send_message(message)
    raise SMTP_DisabledError unless @smtp_options['use_smtp']
    server = @smtp_options["server"]
    port   = @smtp_options['port']
    to     = @smtp_options['email_to'].to_a
    from   = if @smtp_options['name'] 
               '"%s" <%s>' % [@smtp_options["name"], @smtp_options["email_from"]]
             else
               @smtp_options['email_from']
             end
    
    Net::SMTP.start(server,port) do |smtp|
      tries = 0
      smtp.set_debug_output $stderr
      begin
        smtp.send_message(message, from, to)
      rescue TimeoutError
        if tries < 5
          tries += 1
          retry
        else
          $stderr << "ERROR: #{$0} encountered a timeout while attempting to send an e-mail message."
          raise
        end
      end
    end
  end
  
  def create_and_send(subject, message)
    msg = create_message(subject, message)
    begin
      Syslog.log("Sending report",'syslog')
      send_message msg
    rescue SMTP_DisabledError
      Syslog.log("SMTP is disabled. Sending report to standard out.","syslog")
      print message
    end
  end
end