#!/bin/bash
#
# Net Responsibility
#
# Copyright (C) 2007 Scott Severance
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#
# Author:
#	Scott Severance <http://www.scottseverance.us>
#
#
#
# This is the Net Responsibility uninstaller.

if [ `whoami` != root ]; then
  echo "You must run this script as root."
  exit 1
fi

read -p "Are you sure you want to uninstall Net Responsibility? [y/N] " q
if [ -z $q ]; then q=n; fi
if [[ $q = [yY]* ]]; then
  : # do nothing here
else
  exit 0
fi

sharedir=/usr/share/net-responsibility/
confdir=/etc/
initdir=/etc/init.d/
initscript="${initdir}net-responsibility-daemon"
bindir=/usr/local/bin/

$initscript stop
status=$?
sleep 2
if [ $status -ne 0 ]; then
  echo "Unable to stop the Net Responsibility daemon. Aborting."
  exit $status
fi

rm -rf "$sharedir"
rm -f "$initscript"

update-rc.d net-responsibility-daemon remove

#for i in /etc/rc{2,3,4,5}.d; do
#  rm -f "$i/S50net-responsibility-daemon"
#done
#for i in /etc/rc{0,1,6}.d; do
#  rm -f "$i/K50net-responsibility-daemon"
#done

rm -f "${bindir}"net-responsibility-{daemon,report}
rm -f /etc/cron.weekly/net-responsibility-report

read -p "Do you want to delete the log file? [Y/n] " q
if [ -z $q ]; then q=y; fi
if [[ $q = [nN]* ]]; then
  : # do nothing here
else
  if [ -f /var/log/net-responsibility.log ]; then
    rm -f /var/log/net-responsibility.log
  else
    echo "Your log file is in a non-standard location. Please delete it"
    echo "manually."
  fi
fi

read -p "Do you want to delete the configuration file? [Y/n] " q
if [ -z $q ]; then q=y; fi
if [[ $q = [nN]* ]]; then
  : # do nothing here
else
  if [ -f "${confdir}net-responsibility.conf" ]; then
    rm -f "${confdir}net-responsibility.conf"
  else
    echo "Your configuration file is in a non-standard location. Please"
    echo "delete it manually."
  fi
fi

echo "Net Responsibility has been uninstalled."